
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.019.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "download & manage memoir44 scenarios from official website",
  "dist_author" => [
    "Jerome Quelin"
  ],
  "dist_name" => "WWW-DaysOfWonder-Memoir44",
  "dist_version" => "3.000",
  "license" => "perl",
  "module_name" => "WWW::DaysOfWonder::Memoir44",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "App::Cmd::Setup" => 0,
    "Config::Tiny" => 0,
    "DateTime" => 0,
    "Encode" => 0,
    "Exporter::Lite" => 0,
    "File::HomeDir::PathClass" => 0,
    "File::Spec::Functions" => 0,
    "FindBin" => 0,
    "HTML::TreeBuilder" => 0,
    "LWP::UserAgent" => 0,
    "Locale::TextDomain" => 0,
    "Moose" => 0,
    "Moose::Util::TypeConstraints" => 0,
    "MooseX::Getopt::GLD" => 0,
    "MooseX::Has::Sugar" => 0,
    "MooseX::SemiAffordanceAccessor" => 0,
    "MooseX::Singleton" => 0,
    "Path::Class" => 0,
    "Storable" => 0,
    "Term::ProgressBar::Quiet" => 0,
    "Term::Twiddle::Quiet" => 0,
    "Text::Padding" => 0,
    "Text::Trim" => 0,
    "URI" => 0,
    "lib" => 0,
    "overload" => 0,
    "perl" => "5.012",
    "strict" => 0,
    "warnings" => 0
  },
  "script_files" => [
    "bin/mem44"
  ],
  "test_requires" => {
    "File::Spec" => 0,
    "File::Temp" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test::More" => "0.88"
  }
);


my %fallback_build_requires = (
  "File::Spec" => 0,
  "File::Temp" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.3601",
  "Test::More" => "0.88"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
